@@ -5,7 +5,9 @@ use std::cmp::Ordering;
 use std::fmt::Debug;
 
 use bytes::{Buf, BufMut, BytesMut};
+use serbuffer::FieldMetadata;
 
+use crate::core::data_types::Schema;
 use crate::core::runtime::{ChannelKey, CheckpointId};
 use crate::core::watermark::{MAX_WATERMARK, MIN_WATERMARK};
 use crate::core::window::Window;
@@ -22,6 +24,53 @@ pub mod types {
     pub use serbuffer::types::*;
 }
 
+#[derive(Clone, Debug, Serialize, Deserialize)]
+pub enum FnSchema {
+    Empty,
+    Single(Schema),
+    Tuple(Schema, Schema),
+}
+
+impl FnSchema {
+    pub fn first(&self) -> &Schema {
+        match self {
+            Self::Single(v) => v,
+            Self::Tuple(v, _v1) => v,
+            _ => panic!("no schema"),
+        }
+    }
+}
+
+impl<'a> From<&'a Schema> for FnSchema {
+    fn from(schema: &'a Schema) -> Self {
+        FnSchema::Single(schema.clone())
+    }
+}
+
+impl<'a, const N: usize> From<&'a FieldMetadata<N>> for FnSchema {
+    fn from(metadata: &'a FieldMetadata<N>) -> Self {
+        FnSchema::Single(Schema::from(metadata))
+    }
+}
+
+impl Into<Schema> for FnSchema {
+    fn into(self) -> Schema {
+        match self {
+            FnSchema::Single(v) => v,
+            _ => panic!("only support `Single`"),
+        }
+    }
+}
+
+impl Into<(Schema, Schema)> for FnSchema {
+    fn into(self) -> (Schema, Schema) {
+        match self {
+            FnSchema::Tuple(v0, v1) => (v0, v1),
+            _ => panic!("only support `Tuple`"),
+        }
+    }
+}
+
 pub(crate) trait Partition {
     fn partition(&self) -> u16;
     fn set_partition(&mut self, partition: u16);
