@@ -182,7 +182,8 @@ mod tests {
     use crate::core::data_stream::CoStream;
     use crate::core::data_stream::{TConnectedStreams, TKeyedStream};
     use crate::core::data_stream::{TDataStream, TWindowedStream};
-    use crate::core::element::Record;
+    use crate::core::data_types::{DataType, Field, Schema};
+    use crate::core::element::{FnSchema, Record};
     use crate::core::env::StreamExecutionEnvironment;
     use crate::core::function::{
         CoProcessFunction, Context, FlatMapFunction, InputFormat, InputSplit, InputSplitSource,
@@ -345,6 +346,13 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn schema(&self, _input_schema: FnSchema) -> FnSchema {
+            FnSchema::Single(Schema::new(vec![
+                Field::new("a", DataType::Binary),
+                Field::new("b", DataType::Int64),
+            ]))
+        }
     }
 
     #[derive(Serialize, Deserialize, Debug)]
@@ -368,6 +376,10 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn schema(&self, input_schema: FnSchema) -> FnSchema {
+            input_schema
+        }
     }
 
     impl NamedFunction for MyFlatMapFunction {
@@ -388,6 +400,10 @@ mod tests {
     }
 
     impl TimestampAssigner for MyTimestampAssigner {
+        fn open(&mut self, _context: &Context) -> core::Result<()> {
+            Ok(())
+        }
+
         fn extract_timestamp(
             &mut self,
             _row: &mut Record,
@@ -427,6 +443,10 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn key_schema(&self, _input_schema: FnSchema) -> FnSchema {
+            FnSchema::Single(Schema::new(vec![Field::new("a", DataType::Binary)]))
+        }
     }
 
     impl NamedFunction for MyKeySelectorFunction {
@@ -458,6 +478,10 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn schema(&self, _input_schema: FnSchema) -> FnSchema {
+            FnSchema::Single(Schema::new(vec![Field::new("b", DataType::Int64)]))
+        }
     }
 
     impl NamedFunction for MyReduceFunction {
@@ -489,6 +513,10 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn schema(&self, input_schema: FnSchema) -> FnSchema {
+            input_schema
+        }
     }
 
     impl NamedFunction for MyOutputFormat {
@@ -521,6 +549,10 @@ mod tests {
         fn close(&mut self) -> core::Result<()> {
             Ok(())
         }
+
+        fn schema(&self, input_schema: FnSchema) -> FnSchema {
+            input_schema
+        }
     }
 
     impl NamedFunction for MyCoProcessFunction {
